@@ -8,11 +8,17 @@ LOG_FILE = "./mlops_e2e_pipeline.log"
 
 
 def get_logger():
+    """_summary_
+
+    Returns:
+        _type_: _description_
+    """
 
     fmt = (
         "<level>{level: <8}</level> - "
         "<green>{time:YYYY-MM-DD HH:mm:ss.SSS}</green> - "
         f"{APP_LOGGER_NAME} - "
+        "<cyan>{process}</cyan> - "
         "<cyan>{name}</cyan>:<cyan>{function}</cyan>:<cyan>{line}</cyan> - "
         "<level>{message}</level>"
     )
